Stan Math Library: stan/math/prim/mat/fun/cholesky_decompose.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
cholesky_decompose.hpp File Reference
`#include <stan/math/prim/mat/fun/Eigen.hpp>`
`#include <stan/math/prim/mat/err/check_pos_definite.hpp>`
`#include <stan/math/prim/mat/err/check_square.hpp>`
`#include <stan/math/prim/mat/err/check_symmetric.hpp>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T >
Eigen::Matrix< T, Eigen::Dynamic, Eigen::Dynamic > | stan::math::cholesky_decompose (const Eigen::Matrix< T, Eigen::Dynamic, Eigen::Dynamic > &m)
| Return the lower-triangular Cholesky factor (i.e., matrix square root) of the specified square, symmetric matrix. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.